@@ -280,3 +280,21 @@ def test_unexecuted_cursor_rowcount(con):
 def test_unexecuted_cursor_description(con):
     cursor = con.cursor()
     assert cursor.description is None
+
+
+def test_callproc(cursor):
+    cursor.execute("select current_setting('server_version')")
+    version = cursor.fetchall()[0][0].split()[0]
+
+    if not (version.startswith('9') or version.startswith('10')):
+        cursor.execute("""
+CREATE PROCEDURE echo(INOUT val text)
+  LANGUAGE plpgsql AS
+$proc$
+BEGIN
+END
+$proc$;
+""")
+
+        cursor.callproc("echo", ['hello'])
+        assert cursor.fetchall() == (['hello'],)
