@@ -145,14 +145,3 @@ def test_application_name_integer(db_kwargs):
 def test_application_name_bytearray(db_kwargs):
     db_kwargs['application_name'] = bytearray(b'Philby')
     pg8000.native.Connection(**db_kwargs)
-
-
-# This requires a line in pg_hba.conf that requires scram-sha-256 for the
-# database scram-sha-256
-
-def test_scram_sha_256(db_kwargs):
-    db_kwargs["database"] = "pg8000_scram_sha_256"
-
-    # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.native.DatabaseError, match='3D000'):
-        pg8000.native.Connection(**db_kwargs)
